==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/p_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?
			include($templatePath . 'p_menu.inc.php');
			?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td width="560" valign="top">
			<?php
			if (isset($blog)) {
			?>
			<div class="box_top">
				<?php echo $blog['blog_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $blog['blog_title'];?><br />
						</span>
						<?php echo $blog['blog_body_display'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $author['profile_nic'];?><br />
					</td>
				</tr>
			</table>
			<?php }?>
			
			
			<?php
			if (isset($library)) {
			?>
			<div class="box_top">
				<?php echo $library['display_library_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $library['library_title'];?><br />
						</span>
						<?php echo $library['library_body'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $author['profile_nic'];?><br /></td>
				</tr>
			</table>
			<?php }?>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>

==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/template/barnraiser_01/p_item.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?
			include($templatePath . 'p_menu.inc.php');
			?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td width="560" valign="top">
			<?php
			if (isset($blog)) {
			?>
			<div class="box_top">
				<?php echo $blog['blog_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $blog['blog_title'];?><br />
						</span>
						<?php echo $blog['blog_body_display'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_author'];?>: <?php echo $author['profile_nic'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?><br />
					</td>
				</tr>
			</table>
			</div>
			<?php }?>

			<?php
			if (isset($subject)) {
			?>
			<div class="box_top">
				<?php echo $subject['subject_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td valign="top">
						<span class="txt_item_title">
						<?php echo $subject['subject_title'];?><br />
						</span>
						<?php echo $subject['display_subject_body'];?><br />
					</td>
			    </tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_author'];?>: <?php echo $author['profile_nic'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?><br />
					</td>
			    </tr>
			</table>
			</div>
			<?php }?>


			<?php
			if (isset($poll)) {
 			?>
			<div class="box_top">
				<?php echo $poll['poll_start_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
					<td valign="top">
						<?php
						$print_view = 1;
						include $templatePath . "poll_detail.inc.tpl.php";
						?>
					</td>
				</tr>
 			</table>
			</div>
			<?php }?>

			<?php
			if (isset($library)) {
			?>
			<div class="box_top">
				<?php echo $library['display_library_create_datetime'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<span class="txt_item_title">
						<?php echo $library['library_title'];?><br />
						</span>
						<?php echo $library['library_body'];?><br />
					</td>
				</tr>
				<tr>
					<td class="txt_footer">
						<?php echo $lang['txt_author'];?>: <?php echo $author['profile_nic'];?>
						&nbsp;&#47;&nbsp;
						<?php echo $lang['txt_joined'];?>: <?php echo $author['display_profile_create_datetime'];?><br />
					</td>
				</tr>
			</table>
			</div>
			<?php }?>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			
			<?php
			$requested_comment_language_id = null;
			$print_view = 1;
			include $templatePath . "comment.inc.tpl.php";
			?>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
